@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use Moose;
 
@@ -14,9 +14,9 @@ with qw(
   Dist::Zilla::Role::TextTemplate
 );
 
-sub mvp_multivalue_args { return (qw( skip_file stopwords travis_ci_ignore_perl )) }
+sub mvp_multivalue_args { return (qw( skip stopwords travis_ci_ignore_perl )) }
 
-has skip_file => (
+has skip => (
     is      => 'ro',
     isa     => 'Maybe[ArrayRef]',
     default => sub { [] },
@@ -110,7 +110,7 @@ sub munge_files {
 sub _write_files {
     my ($self) = @_;
 
-    my %file_to_skip = map { $_ => 1 } grep { defined && !m{ ^ \s* $ }xsm } @{ $self->skip_file };
+    my %file_to_skip = map { $_ => 1 } grep { defined && !m{ ^ \s* $ }xsm } @{ $self->skip };
 
   FILE:
     for my $file ( map { path($_) } sort $self->files() ) {
@@ -150,7 +150,7 @@ Dist::Zilla::Plugin::Author::SKIRMESS::RepositoryBase - Automatically create and
 
 =head1 VERSION
 
-Version 0.020
+Version 0.021
 
 =head1 SYNOPSIS
 
@@ -789,7 +789,7 @@ The following configuration options are supported:
 
 =item *
 
-C<skip_file> - Defines files to be skipped (not generated).
+C<skip> - Defines files to be skipped (not generated).
 
 =item *
 
